@@ -1,11 +1,13 @@
 
 from urllib import urlopen, urlencode
 
-from django import template
 from django.conf import settings
+from django.utils.html import strip_tags
 from django.utils.simplejson import loads
 
 from mezzanine import settings as mezzanine_settings
+from mezzanine import template
+from mezzanine.utils import decode_html_entities
 
 
 register = template.Library()
@@ -22,43 +24,8 @@ def setting(setting_name):
         value = ""
     return value
 
-def register_as_tag(register):
-    """
-    Decorator that creates a tag with the format: {% func_name as var_name %}
-    The decorated func returns the value that is given to var_name in the 
-    template context.
-    """
-    def wrapper(func):
-        def tag(parser, token):
-            class TagNode(template.Node):
-                def render(self, context):
-                    parts = token.split_contents()
-                    context[parts[-1]] = func(*parts[1:-2])
-                    return ""
-            return TagNode()
-        for copy_attr in ("__dict__", "__doc__", "__name__"):
-            setattr(tag, copy_attr, getattr(func, copy_attr))
-        return register.tag(tag)
-    return wrapper
 
-def register_render_tag(register):
-    """
-    Decorator that creates a template tag using the given renderer as the 
-    render function for the template tag node - the render function takes two 
-    arguments - the template context and the tag token.
-    """
-    def wrapper(renderer):
-        def tag(parser, token):
-            class TagNode(template.Node):
-                def render(self, context):
-                    return renderer(context, token)
-            return TagNode()
-        for copy_attr in ("__dict__", "__doc__", "__name__"):
-            setattr(tag, copy_attr, getattr(renderer, copy_attr))
-        return register.tag(tag)
-    return wrapper
-
-@register_render_tag(register)
+@register.render_tag
 def set_short_url_for(context, token):
     """
     Sets the ``short_url`` attribute of the given model using the bit.ly 
@@ -81,11 +48,11 @@ def set_short_url_for(context, token):
                 obj.save()
     return ""
 
-@register_render_tag(register)
+@register.render_tag
 def admin_reorder(context, token):
     """
-    Called in admin/base_site.html template override and applies custom ordering 
-    of apps/models defined by settings.ADMIN_REORDER.
+    Called in ``admin/base_site.html`` template override and applies custom 
+    ordering of apps/models defined by ``settings.ADMIN_REORDER``.
     """
     # sort key function - use index of item in order if exists, otherwise item
     sort = lambda order, item: (order.index(item), "") if item in order else (
@@ -105,3 +72,12 @@ def admin_reorder(context, token):
                 sort(model_order, model["admin_url"].strip("/").split("/")[-1]))
     return ""
 
+@register.to_end_tag
+def metablock(parsed):
+    """
+    Remove HTML tags, entities and superfluous characters from meta blocks.
+    """
+    parsed = " ".join(parsed.replace("\n", "").split()).replace(" ,", ",")
+    return strip_tags(decode_html_entities(parsed))
+
+
